# == Class: nagios::nrpe::iostat
#
# A wrapper class that will break up the fact $::used_blockdevices into its
# constituent parts and pass it to the iostat check
# nagios::nrpe::blockdevice::iostat. It also has one extra bit - an extra
# section that tests for lvm usage and adds checks for these.
#
# It would be sensible in the future to combine this with diskspace and inodes
# into a single blockdevice check, but all have exceptional sections that would
# be then branched out.
#
# It also has a slightly complicated section that generates a service group per
# xen host on the nagios server. This requires server logic (and some
# interesting logic here) to ensure that it does not try and create a single
# service group multiple times. This requires the nagios::server::iostat class.
#
# It will also make sure load not also trigger if this has triggered, and so
# requires nagios::nrpe::load.
#
# === Parameters
#
# [*monitoring_environment*]
#   This is the environment that the check will be submitted for. This will
#   default to the value set by nagios::nrpe::config but can be overridden here.
#   Not required. This will override the value for the define that it
#   implements.
#
# [*nagios_service*]
#   This is the generic service that this check will implement. This should
#   be set by nagios::nrpe::config but can be overridden here. Not required.
#   This will override the value for the define that it implements.
#
# [*nagios_alias*]
#   This is the hostname that the check will be submitted for. This should
#   almost always be the hostname, but could be overriden, for instance when
#   submitting a check for a virtual ip. Not required. This will override the
#   value for the define that it implements.
#
# === Variables
#
# [*drive*]
#   This is an array built from the blockdevices fact. It should be an array of
#   all the drives.
#
# === Authors
#
# Ben Field <ben.field@concreteplatform.com>
class nagios::nrpe::iostat (
  $monitoring_environment = $::nagios::nrpe::config::monitoring_environment,
  $nagios_service         = $::nagios::nrpe::config::nagios_service,
  $nagios_alias           = $::hostname,) {
  require nagios::nrpe::config
  require base::sysstat
  include nagios::nrpe::service

  require nagios::nrpe::checks::iostat

  # This is a bit dirty. We could use nagios_servicegroups, but we want some way
  # to be dynamic with our iostat service
  # groups.
  # Easiest way is to throw it all together into a single text file using
  # datacat. Gonna add the xenhost name into the
  # array.

  @@datacat_fragment { "${::fqdn} iostat in servicegroup":
    target => '/etc/nagios3/conf.d/puppet/servicegroups_iostat.cfg',
    data   => {
      host => [$::xenhost],
    }
    ,
    tag    => "iostat_${monitoring_environment}",
  }

  $drive = split($::used_blockdevices, ',')

  nagios::nrpe::blockdevice::iostat { $drive:
    monitoring_environment => $monitoring_environment,
    nagios_service         => $nagios_service,
    nagios_alias           => $nagios_alias,
  }

}
